# SOTAI

[![](https://img.shields.io/pypi/v/sotai)](https://pypi.org/project/sotai/) [![](https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml)

A Library For Interpretable Machine Learning. This library is a PyTorch implementation of modeling techniques found in [Monotonic Calibrated Interpolated Look-Up Tables](https://jmlr.org/papers/volume17/15-243/15-243.pdf).

Installing the package:

```shell
pip install sotai
```

Importing the package:

```python
import sotai
```

## SDK Documentation

You can find documentation for this SDK at [https://docs.sotai.ai/v/sdk-ref](https://docs.sotai.ai/v/sdk-ref) or in the repo [docs folder](./).

## Web Client User Documentation

You can find documentation for how to use the hosted web client at [https://docs.sotai.ai/](https://docs.sotai.ai/)

## Contribution Guidelines

See the guide on [contributing](CONTRIBUTING.md) for full details on how to contribute to the library. For any feature and/or bug requests, visit our [Issues](https://github.com/SOTAI-Labs/sotai/issues).

## Examples

For detailed examples on how to use the library, see [examples](https://github.com/SOTAI-Labs/sotai/tree/main/docs/examples).

## License

[MIT](../LICENSE/)
